==> lutool-boot-1.0.2-sources.jar: net/dreamlu/boot/config/HttpCacheConfiguration.java <==
package net.dreamlu.boot.config;

import net.dreamlu.boot.cache.http.HttpCacheInterceptor;
import net.dreamlu.boot.cache.http.HttpCacheService;
import net.dreamlu.boot.properties.DreamHttpCacheProperties;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.web.WebMvcProperties;
import org.springframework.cache.CacheManager;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurerAdapter;

import java.util.List;

/**
 * 国际化配置
 *
 * @author L.cm
 */
@Configuration
@ConditionalOnProperty(value = "dream.http.cache.enabled", havingValue = "true")
public class HttpCacheConfiguration extends WebMvcConfigurerAdapter {

	private final WebMvcProperties webMvcProperties;
	private final DreamHttpCacheProperties properties;
	private final CacheManager cacheManager;

	public HttpCacheConfiguration(DreamHttpCacheProperties properties, WebMvcProperties webMvcProperties, CacheManager cacheManager) {
		this.webMvcProperties = webMvcProperties;
		this.properties = properties;
		this.cacheManager = cacheManager;
	}

	@Bean
	public HttpCacheService httpCacheService() {
		return new HttpCacheService(properties, cacheManager);
	}

	@Override
	public void addInterceptors(InterceptorRegistry registry) {
		List<String> excludePatterns = properties.getExcludePatterns();
		excludePatterns.add(webMvcProperties.getStaticPathPattern());
		HttpCacheInterceptor httpCacheInterceptor = new HttpCacheInterceptor(httpCacheService());
		registry.addInterceptor(httpCacheInterceptor)
			.addPathPatterns(properties.getIncludePatterns().toArray(new String[0]))
			.excludePathPatterns(excludePatterns.toArray(new String[0]));
	}
}

==> lutool-boot-1.0.3-sources.jar: net/dreamlu/boot/config/HttpCacheConfiguration.java <==
/*
 * *************************************************************************
 *   Copyright (c) 2018-2025, dreamlu.net All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the dreamlu.net developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: chunmeng.lu (qq596392912@gmail.com)
 * *************************************************************************
 */

package net.dreamlu.boot.config;

import lombok.AllArgsConstructor;
import net.dreamlu.boot.cache.http.HttpCacheInterceptor;
import net.dreamlu.boot.cache.http.HttpCacheService;
import net.dreamlu.boot.properties.DreamHttpCacheProperties;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.autoconfigure.web.WebMvcProperties;
import org.springframework.cache.CacheManager;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurerAdapter;

import java.util.List;

/**
 * 国际化配置
 *
 * @author L.cm
 */
@Configuration
@ConditionalOnProperty(value = "dream.http.cache.enabled", havingValue = "true")
@AllArgsConstructor
public class HttpCacheConfiguration extends WebMvcConfigurerAdapter {
	private final WebMvcProperties webMvcProperties;
	private final DreamHttpCacheProperties properties;
	private final CacheManager cacheManager;

	@Bean
	public HttpCacheService httpCacheService() {
		return new HttpCacheService(properties, cacheManager);
	}

	@Override
	public void addInterceptors(InterceptorRegistry registry) {
		List<String> excludePatterns = properties.getExcludePatterns();
		excludePatterns.add(webMvcProperties.getStaticPathPattern());
		HttpCacheInterceptor httpCacheInterceptor = new HttpCacheInterceptor(httpCacheService());
		registry.addInterceptor(httpCacheInterceptor)
			.addPathPatterns(properties.getIncludePatterns().toArray(new String[0]))
			.excludePathPatterns(excludePatterns.toArray(new String[0]));
	}
}
